@@ -13,20 +13,17 @@ from PySide6 import QtCore, QtWidgets
 from normcap import __version__
 from normcap.gui import system_info, utils
 from normcap.gui.tray import SystemTray
-from normcap.utils import create_argparser, set_environ_for_prebuild_package
+from normcap.utils import (
+    create_argparser,
+    init_logger,
+    set_environ_for_prebuild_package,
+)
 
 set_environ_for_prebuild_package()
 
-logging.basicConfig(
-    format="%(asctime)s - %(levelname)-7s - %(name)s:%(lineno)d - %(message)s",
-    datefmt="%H:%M:%S",
-    level="WARNING",
-)
-
 
 def main():
     """Start main application logic."""
-    logger = logging.getLogger("normcap")
     sys.excepthook = utils.hook_exceptions
 
     # Allow closing QT app with CTRL+C in terminal
@@ -34,7 +31,8 @@ def main():
 
     args = create_argparser().parse_args()
 
-    logger.setLevel(args.verbosity.upper())
+    init_logger(level=args.verbosity.upper())
+    logger = logging.getLogger("normcap")
     logger.info("Start NormCap v%s", __version__)
 
     if system_info.display_manager_is_wayland():
